@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_conn.c,v 1.15 2001/04/12 02:59:31 wensong Exp $
+ * Version:     $Id: ip_vs_conn.c,v 1.15.2.1 2001/04/19 08:50:43 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -1148,8 +1148,10 @@ void ip_vs_unbind_dest(struct ip_vs_conn *cp)
                  *  Decrease the refcnt of the dest, and free the dest
                  *  if nobody refers to it (refcnt=0).
                  */
-                if (atomic_dec_and_test(&dest->refcnt))
+                if (atomic_dec_and_test(&dest->refcnt)) {
+                        __ip_vs_dst_reset(dest);
                         kfree(dest);
+                }
         }
 }
 
