@@ -1,7 +1,7 @@
 /*
  * IP_VS        ftp application module
  *
- * Version:	$Id: ip_vs_ftp.c,v 1.4 2001/02/23 09:15:05 wensong Exp $
+ * Version:	$Id: ip_vs_ftp.c,v 1.5 2001/03/18 15:01:45 wensong Exp $
  *
  * Authors:	Wensong Zhang <wensong@linuxvirtualserver.org>
  *		
@@ -152,6 +152,10 @@ static int ip_vs_ftp_out(struct ip_vs_app *mapp,
         unsigned buf_len;
 	int diff;
 
+	/* Only useful for established sessions */
+	if (cp->state != IP_VS_S_ESTABLISHED) 
+		return 0;
+
 	if (cp->app_data == &ip_vs_ftp_pasv) {
                 skb = *skb_p;
                 iph = skb->nh.iph;
@@ -254,6 +258,10 @@ static int ip_vs_ftp_in(struct ip_vs_app *mapp,
 	__u16 port;
 	struct ip_vs_conn *n_cp;
 
+	/* Only useful for established sessions */
+	if (cp->state != IP_VS_S_ESTABLISHED) 
+		return 0;
+
 	/*
 	 * Detecting whether it is passive
 	 */
